@@ -1,23 +1,13 @@
-# test_operations.py - unit tests for the operations module
-#
-# Copyright 2015 NetworkX developers.
-#
-# This file is part of NetworkX.
-#
-# NetworkX is distributed under a BSD license; see LICENSE.txt for more
-# information.
 """Unit tests for the :mod:`networkx.algorithms.tree.operations` module.
 
 """
-from nose.tools import assert_equal
-from nose.tools import assert_true
 
 import networkx as nx
 from networkx.testing import assert_nodes_equal
 from networkx.testing import assert_edges_equal
 
 
-class TestJoin(object):
+class TestJoin:
     """Unit tests for the :func:`networkx.tree.join` function."""
 
     def test_empty_sequence(self):
@@ -26,8 +16,8 @@ class TestJoin(object):
 
         """
         T = nx.join([])
-        assert_equal(len(T), 1)
-        assert_equal(T.number_of_edges(), 0)
+        assert len(T) == 1
+        assert T.number_of_edges() == 0
 
     def test_single(self):
         """Tests that joining just one tree yields a tree with one more
@@ -45,4 +35,4 @@ class TestJoin(object):
         trees = [(nx.full_rary_tree(2, 2 ** 2 - 1), 0) for i in range(2)]
         actual = nx.join(trees)
         expected = nx.full_rary_tree(2, 2 ** 3 - 1)
-        assert_true(nx.is_isomorphic(actual, expected))
+        assert nx.is_isomorphic(actual, expected)
