@@ -8,7 +8,7 @@ Do not add this file to the repository.
 import datetime
 
 version = '2.5.1'
-date = 'Wed Apr  7 01:01:32 2021'
+date = 'Fri May  7 19:44:08 2021'
 
 # Was NetworkX built from a development version? If so, remember that the major
 # and minor versions reference the "target" (rather than "current") release.
@@ -18,7 +18,7 @@ dev = False
 version_info = ('networkx', '2', '5.1', None)
 
 # Format: a 'datetime.datetime' instance
-date_info = datetime.datetime(2021, 4, 7, 1, 1, 32)
+date_info = datetime.datetime(2021, 5, 7, 19, 44, 8)
 
 # Format: (vcs, vcs_tuple)
 vcs_info = (None, (None, None))
