@@ -1,4 +1,3 @@
-#! /usr/bin/env python
 """
 ==============
 Directed Graph
@@ -8,7 +7,6 @@ Draw a graph with directed edges using a colormap and different node sizes.
 
 Edges have different colors and alphas (opacity). Drawn using matplotlib.
 """
-# Author: Rodrigo Dorantes-Gilardi (rodgdor@gmail.com)
 
 import matplotlib as mpl
 import matplotlib.pyplot as plt
@@ -22,10 +20,17 @@ M = G.number_of_edges()
 edge_colors = range(2, M + 2)
 edge_alphas = [(5 + i) / (M + 4) for i in range(M)]
 
-nodes = nx.draw_networkx_nodes(G, pos, node_size=node_sizes, node_color='blue')
-edges = nx.draw_networkx_edges(G, pos, node_size=node_sizes, arrowstyle='->',
-                               arrowsize=10, edge_color=edge_colors,
-                               edge_cmap=plt.cm.Blues, width=2)
+nodes = nx.draw_networkx_nodes(G, pos, node_size=node_sizes, node_color="blue")
+edges = nx.draw_networkx_edges(
+    G,
+    pos,
+    node_size=node_sizes,
+    arrowstyle="->",
+    arrowsize=10,
+    edge_color=edge_colors,
+    edge_cmap=plt.cm.Blues,
+    width=2,
+)
 # set alpha value for each edge
 for i in range(M):
     edges[i].set_alpha(edge_alphas[i])
